==> jakarta-jmeter_2.3.4.orig.tar.gz: jakarta-jmeter-2.3.4/src/components/org/apache/jmeter/extractor/DebugPostProcessor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.jmeter.extractor;

import org.apache.jmeter.processor.PostProcessor;
import org.apache.jmeter.samplers.SampleResult;
import org.apache.jmeter.testbeans.TestBean;
import org.apache.jmeter.testelement.AbstractTestElement;
import org.apache.jmeter.testelement.property.JMeterProperty;
import org.apache.jmeter.testelement.property.PropertyIterator;
import org.apache.jmeter.threads.JMeterContext;

/**
 * Debugging Post-Processor: creates a subSample containing the variables defined in the previous sampler.
 */
public class DebugPostProcessor extends AbstractTestElement implements PostProcessor, TestBean {

    public void process(){
        StringBuffer sb = new StringBuffer(100);
        JMeterContext threadContext = getThreadContext();
        PropertyIterator i = threadContext.getCurrentSampler().propertyIterator();
        while(i.hasNext())
        {
            JMeterProperty prop = i.next();
            sb.append(prop.getName());
            sb.append("=");
            sb.append(prop.getStringValue());
            sb.append("\n");
         }
         SampleResult sr = new SampleResult();
         sr.setResponseData(sb.toString().getBytes());
         sr.setDataType("text");
         sr.setSampleLabel(getName());
         sr.setSuccessful(true);
         sr.setSamplerData("SamplerPropertyValues");
         threadContext.getPreviousResult().addSubResult(sr);
    }
}

==> jakarta-jmeter_2.5.1.orig.tar.gz: jakarta-jmeter-2.5.1/src/components/org/apache/jmeter/extractor/DebugPostProcessor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.jmeter.extractor;

import org.apache.jmeter.processor.PostProcessor;
import org.apache.jmeter.samplers.SampleResult;
import org.apache.jmeter.testbeans.TestBean;
import org.apache.jmeter.testelement.AbstractTestElement;
import org.apache.jmeter.testelement.property.JMeterProperty;
import org.apache.jmeter.testelement.property.PropertyIterator;
import org.apache.jmeter.threads.JMeterContext;

/**
 * Debugging Post-Processor: creates a subSample containing the variables defined in the previous sampler.
 */
public class DebugPostProcessor extends AbstractTestElement implements PostProcessor, TestBean {

    private static final long serialVersionUID = 240L;

    public void process(){
        StringBuilder sb = new StringBuilder(100);
        JMeterContext threadContext = getThreadContext();
        PropertyIterator i = threadContext.getCurrentSampler().propertyIterator();
        while(i.hasNext())
        {
            JMeterProperty prop = i.next();
            sb.append(prop.getName());
            sb.append("=");
            sb.append(prop.getStringValue());
            sb.append("\n");
         }
         SampleResult sr = new SampleResult();
         sr.setResponseData(sb.toString(), null);
         sr.setDataType(SampleResult.TEXT);
         sr.setSampleLabel(getName());
         sr.setSuccessful(true);
         sr.setSamplerData("SamplerPropertyValues");
         threadContext.getPreviousResult().addSubResult(sr);
    }
}
